@@ -74,9 +74,11 @@ pub struct Lock<'info> {
     #[account(mut)]
     pub locker: Account<'info, Locker>,
 
+    /// [Escrow].
     #[account(mut)]
     pub escrow: Account<'info, Escrow>,
 
+    /// TODO(michael): Write docs.
     #[account(mut)]
     pub escrow_tokens: Account<'info, TokenAccount>,
 
@@ -92,10 +94,12 @@ pub struct Lock<'info> {
 /// Accounts for [locked_voter::exit].
 #[derive(Accounts)]
 pub struct Exit<'info> {
+    /// TODO(michael): Write docs.
     #[account(mut)]
     pub locker: Account<'info, Locker>,
 
-    #[account(mut)]
+    /// The [Escrow] that is voting.
+    #[account(mut, close = payer)]
     pub escrow: Account<'info, Escrow>,
 
     /// Authority of the [Escrow].
@@ -107,6 +111,10 @@ pub struct Exit<'info> {
     #[account(mut)]
     pub destination_tokens: Account<'info, TokenAccount>,
 
+    /// The payer to receive the rent refund.
+    #[account(mut)]
+    pub payer: Signer<'info>,
+
     /// Token program.
     pub token_program: Program<'info, Token>,
 }
@@ -151,3 +159,15 @@ pub struct CastVote<'info> {
     /// The [govern] program.
     pub govern_program: Program<'info, govern::program::Govern>,
 }
+
+/// Accounts for [locked_voter::cast_vote].
+#[derive(Accounts)]
+pub struct SetLockerParams<'info> {
+    /// The [Locker].
+    #[account(mut)]
+    pub locker: Account<'info, Locker>,
+    /// The [Governor].
+    pub governor: Account<'info, Governor>,
+    /// The smart wallet on the [Governor].
+    pub smart_wallet: Signer<'info>,
+}
