@@ -26,11 +26,11 @@ impl<'info> Exit<'info> {
         let locker = &mut self.locker;
         locker.locked_supply = unwrap_int!(locker.locked_supply.checked_sub(self.escrow.amount));
 
-        // update the escrow
-        let escrow = &mut self.escrow;
-        escrow.amount = 0;
-        escrow.escrow_started_at = -1;
-        escrow.escrow_ends_at = -1;
+        emit!(ExitEscrowEvent {
+            escrow_owner: self.escrow.owner,
+            locker: locker.key(),
+            timestamp: Clock::get()?.unix_timestamp,
+        });
 
         Ok(())
     }
@@ -41,6 +41,13 @@ impl<'info> Validate<'info> for Exit<'info> {
         assert_keys_eq!(self.locker, self.escrow.locker);
         assert_keys_eq!(self.escrow.owner, self.escrow_owner);
         assert_keys_eq!(self.escrow.tokens, self.escrow_tokens);
+        let now = Clock::get()?.unix_timestamp;
+        msg!(
+            "now: {}; escrow_ends_at: {}",
+            now,
+            self.escrow.escrow_ends_at
+        );
+        invariant!(self.escrow.escrow_ends_at < now, "escrow has not ended");
         Ok(())
     }
 }
