@@ -16,9 +16,16 @@ impl<'info> NewEscrow<'info> {
             &self.locker.token_mint,
         );
         escrow.amount = 0;
-        escrow.escrow_started_at = -1;
-        escrow.escrow_ends_at = -1;
+        escrow.escrow_started_at = 0;
+        escrow.escrow_ends_at = 0;
         escrow.vote_delegate = self.escrow_owner.key();
+
+        emit!(NewEscrowEvent {
+            escrow_owner: escrow.owner,
+            locker: escrow.locker,
+            timestamp: Clock::get()?.unix_timestamp,
+        });
+
         Ok(())
     }
 }
