@@ -10,11 +10,13 @@ use govern::Governor;
 use vipers::*;
 
 pub mod account_structs;
+mod events;
 mod instructions;
 pub mod locker;
 mod state;
 
 use account_structs::*;
+pub use events::*;
 pub use state::*;
 
 declare_id!("VETi1zHeH8qcWfDRyUzUvEZ7DFWs46ETNYMZjMLivHz");
@@ -64,11 +66,10 @@ pub mod locked_voter {
     pub fn cast_vote(ctx: Context<CastVote>, side: u8) -> ProgramResult {
         ctx.accounts.cast_vote(side)
     }
-}
 
-/// Error codes.
-#[error]
-pub enum ErrorCode {
-    #[msg("test")]
-    Unauthorized,
+    /// Set locker params.
+    #[access_control(ctx.accounts.validate())]
+    pub fn set_locker_params(ctx: Context<SetLockerParams>, params: LockerParams) -> ProgramResult {
+        ctx.accounts.set_locker_params(params)
+    }
 }
